@@ -288,15 +288,13 @@ class ReboticsBaseProvider(object):
             'role': self.role
         }))
 
-    def set_retailer_identifier(self, retailer_id, retailer_secret_key):
-        self.headers['x-retailer-id'] = retailer_id
+    def set_retailer_identifier(self, retailer_codename, retailer_secret_key):
+        self.headers['x-retailer-codename'] = retailer_codename
         self.headers['x-retailer-secret-key'] = retailer_secret_key
 
     def is_retailer_identifier_used(self):
         header_keys = self.headers.keys()
-        return ('x-retailer-codename' in header_keys or 'x-retailer-id' in header_keys) \
-               and \
-               ('x-retailer-secret-key' in header_keys)
+        return ('x-retailer-codename' in header_keys) and ('x-retailer-secret-key' in header_keys)
 
 
 class PageResult(dict):
